"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseToManifestEntriesArray = void 0;
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const core_1 = require("@salesforce/core");
const kit_1 = require("@salesforce/kit");
const mdapiRetrieveApi_1 = require("../mdapi/mdapiRetrieveApi");
const PathUtil = require("../source/sourcePathUtil");
/**
 * Parse the manifest file and create a list ManifestEntry objects.
 *
 * @param manifestPath {string} The filepath for the manifest
 * @returns {ManifestEntry[]} An array for ManifestEntry objects from the manifest.
 */
exports.parseToManifestEntriesArray = async function (manifestPath) {
    const entries = [];
    const options = {
        unpackaged: manifestPath,
    };
    return mdapiRetrieveApi_1.MdRetrieveApi._getPackageJson(undefined, options).then((manifestJson) => {
        kit_1.ensureArray(manifestJson.types).forEach((type) => {
            if (!type.name) {
                core_1.Messages.importMessagesDirectory(__dirname);
                const messages = core_1.Messages.loadMessages('salesforce-alm', 'mdapi_deploy');
                throw messages.createError('IllFormattedManifest', ['; <name> is missing']);
            }
            kit_1.ensureArray(type.members).forEach((member) => {
                const _member = PathUtil.replaceForwardSlashes(member);
                entries.push({
                    type: type.name,
                    name: _member,
                });
            });
        });
        return entries;
    });
};

//# sourceMappingURL=parseManifestEntriesArray.js.map
